@@ -29,17 +29,17 @@
 #include <QtPlugin>
 #endif
 
-QRegExp FileBoomPlugin::FILE_REGEXP("(http(s|)://fboom\\.me|)/file/url\\.html\\?file=[^'\"]+");
-QString FileBoomPlugin::LOGIN_URL("http://fboom.me/login.html");
-QString FileBoomPlugin::RECAPTCHA_PLUGIN_ID("genericrecaptcha");
+const QRegExp FileBoomPlugin::FILE_REGEXP("(http(s|)://fboom\\.me|)/file/url\\.html\\?file=[^'\"]+");
+const QString FileBoomPlugin::LOGIN_URL("http://fboom.me/login.html");
+const QString FileBoomPlugin::RECAPTCHA_PLUGIN_ID("qdl2-genericrecaptcha");
 #if QT_VERSION >= 0x050000
-QString FileBoomPlugin::CONFIG_FILE(QStandardPaths::writableLocation(QStandardPaths::HomeLocation)
-                                    + "/.config/qdl2/plugins/fileboom");
+const QString FileBoomPlugin::CONFIG_FILE(QStandardPaths::writableLocation(QStandardPaths::HomeLocation)
+                                          + "/.config/qdl2/plugins/qdl2-fileboom");
 #else
-QString FileBoomPlugin::CONFIG_FILE(QDesktopServices::storageLocation(QDesktopServices::HomeLocation)
-                                    + "/.config/qdl2/plugins/fileboom");
+const QString FileBoomPlugin::CONFIG_FILE(QDesktopServices::storageLocation(QDesktopServices::HomeLocation)
+                                          + "/.config/qdl2/plugins/qdl2-fileboom");
 #endif
-int FileBoomPlugin::MAX_REDIRECTS = 8;
+const int FileBoomPlugin::MAX_REDIRECTS = 8;
 
 FileBoomPlugin::FileBoomPlugin(QObject *parent) :
     ServicePlugin(parent),
@@ -50,6 +50,16 @@ FileBoomPlugin::FileBoomPlugin(QObject *parent) :
 {
 }
 
+QString FileBoomPlugin::getRedirect(const QNetworkReply *reply) {
+    QString redirect = QString::fromUtf8(reply->rawHeader("Location"));
+    
+    if (redirect.startsWith("/")) {
+        redirect.prepend(reply->url().scheme() + "://" + reply->url().authority());
+    }
+    
+    return redirect;
+}
+
 ServicePlugin* FileBoomPlugin::createPlugin(QObject *parent) {
     return new FileBoomPlugin(parent);
 }
@@ -101,19 +111,14 @@ void FileBoomPlugin::checkUrlIsValid() {
         return;
     }
 
-    QUrl redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
-
-    if (redirect.isEmpty()) {
-        redirect = reply->header(QNetworkRequest::LocationHeader).toString();
-    }
-
+    const QString redirect = getRedirect(reply);
+    
     if (!redirect.isEmpty()) {
-        if (m_redirects < MAX_REDIRECTS) {
-            if (redirect.host().isEmpty()) {
-                redirect.setScheme("http");
-                redirect.setHost("fboom.me");
-            }
-            
+        if (FILE_REGEXP.indexIn(redirect) == 0) {
+            emit urlChecked(UrlResult(reply->request().url().toString(),
+                            redirect.mid(redirect.lastIndexOf("/") + 1)));
+        }
+        else if (m_redirects < MAX_REDIRECTS) {
             followRedirect(redirect, SLOT(checkUrlIsValid()));
         }
         else {
@@ -213,32 +218,14 @@ void FileBoomPlugin::checkDownloadRequest() {
         return;
     }
 
-    QString redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
-
-    if (redirect.isEmpty()) {
-        redirect = reply->header(QNetworkRequest::LocationHeader).toString();
-    }
-
+    const QString redirect = getRedirect(reply);
+    
     if (!redirect.isEmpty()) {
         if (FILE_REGEXP.indexIn(redirect) == 0) {
-            QUrl url(redirect);
-            
-            if (url.host().isEmpty()) {
-                url.setScheme("http");
-                url.setHost("fboom.me");
-            }
-            
-            emit downloadRequest(QNetworkRequest(url));
+            emit downloadRequest(QNetworkRequest(redirect));
         }
         else if (m_redirects < MAX_REDIRECTS) {
-            QUrl url(redirect);
-            
-            if (url.host().isEmpty()) {
-                url.setScheme("http");
-                url.setHost("fboom.me");
-            }
-            
-            followRedirect(url, SLOT(checkDownloadRequest()));
+            followRedirect(redirect, SLOT(checkDownloadRequest()));
         }
         else {
             emit error(tr("Maximum redirects reached"));
@@ -263,11 +250,10 @@ void FileBoomPlugin::checkDownloadRequest() {
     const QString response = QString::fromUtf8(reply->readAll());
 
     if (FILE_REGEXP.indexIn(response) != -1) {
-        QUrl url(FILE_REGEXP.cap());
+        QString url = FILE_REGEXP.cap();
         
-        if (url.host().isEmpty()) {
-            url.setScheme("http");
-            url.setHost("fboom.me");
+        if (url.startsWith("/")) {
+            url.prepend(reply->url().scheme() + "://" + reply->url().authority());
         }
         
         emit downloadRequest(QNetworkRequest(url));
@@ -310,32 +296,14 @@ void FileBoomPlugin::checkWaitTime() {
         return;
     }
 
-    QString redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
-
-    if (redirect.isEmpty()) {
-        redirect = reply->header(QNetworkRequest::LocationHeader).toString();
-    }
-
+    const QString redirect = getRedirect(reply);
+    
     if (!redirect.isEmpty()) {
         if (FILE_REGEXP.indexIn(redirect) == 0) {
-            QUrl url(redirect);
-            
-            if (url.host().isEmpty()) {
-                url.setScheme("http");
-                url.setHost("fboom.me");
-            }
-            
-            emit downloadRequest(QNetworkRequest(url));
+            emit downloadRequest(QNetworkRequest(redirect));
         }
         else if (m_redirects < MAX_REDIRECTS) {
-            QUrl url(redirect);
-            
-            if (url.host().isEmpty()) {
-                url.setScheme("http");
-                url.setHost("fboom.me");
-            }
-            
-            followRedirect(url, SLOT(checkWaitTime()));
+            followRedirect(redirect, SLOT(checkWaitTime()));
         }
         else {
             emit error(tr("Maximum redirects reached"));
@@ -360,11 +328,10 @@ void FileBoomPlugin::checkWaitTime() {
     const QString response = QString::fromUtf8(reply->readAll());
 
     if (FILE_REGEXP.indexIn(response) != -1) {
-        QUrl url(FILE_REGEXP.cap());
+        QString url = FILE_REGEXP.cap();
         
-        if (url.host().isEmpty()) {
-            url.setScheme("http");
-            url.setHost("fboom.me");
+        if (url.startsWith("/")) {
+            url.prepend(reply->url().scheme() + "://" + reply->url().authority());
         }
         
         emit downloadRequest(QNetworkRequest(url));
@@ -416,32 +383,14 @@ void FileBoomPlugin::checkCaptcha() {
         return;
     }
 
-    QString redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
-
-    if (redirect.isEmpty()) {
-        redirect = reply->header(QNetworkRequest::LocationHeader).toString();
-    }
-
+    const QString redirect = getRedirect(reply);
+    
     if (!redirect.isEmpty()) {
         if (FILE_REGEXP.indexIn(redirect) == 0) {
-            QUrl url(redirect);
-            
-            if (url.host().isEmpty()) {
-                url.setScheme("http");
-                url.setHost("fboom.me");
-            }
-            
-            emit downloadRequest(QNetworkRequest(url));
+            emit downloadRequest(QNetworkRequest(redirect));
         }
         else if (m_redirects < MAX_REDIRECTS) {
-            QUrl url(redirect);
-            
-            if (url.host().isEmpty()) {
-                url.setScheme("http");
-                url.setHost("fboom.me");
-            }
-            
-            followRedirect(url, SLOT(checkCaptcha()));
+            followRedirect(redirect, SLOT(checkCaptcha()));
         }
         else {
             emit error(tr("Maximum redirects reached"));
@@ -466,11 +415,10 @@ void FileBoomPlugin::checkCaptcha() {
     const QString response = QString::fromUtf8(reply->readAll());
 
     if (FILE_REGEXP.indexIn(response) != -1) {
-        QUrl url(FILE_REGEXP.cap());
+        QString url = FILE_REGEXP.cap();
         
-        if (url.host().isEmpty()) {
-            url.setScheme("http");
-            url.setHost("fboom.me");
+        if (url.startsWith("/")) {
+            url.prepend(reply->url().scheme() + "://" + reply->url().authority());
         }
         
         emit downloadRequest(QNetworkRequest(url));
@@ -519,32 +467,14 @@ void FileBoomPlugin::checkDownloadLink() {
         return;
     }
 
-    QString redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
-
-    if (redirect.isEmpty()) {
-        redirect = reply->header(QNetworkRequest::LocationHeader).toString();
-    }
-
+    const QString redirect = getRedirect(reply);
+    
     if (!redirect.isEmpty()) {
         if (FILE_REGEXP.indexIn(redirect) == 0) {
-            QUrl url(redirect);
-            
-            if (url.host().isEmpty()) {
-                url.setScheme("http");
-                url.setHost("fboom.me");
-            }
-            
-            emit downloadRequest(QNetworkRequest(url));
+            emit downloadRequest(QNetworkRequest(redirect));
         }
         else if (m_redirects < MAX_REDIRECTS) {
-            QUrl url(redirect);
-            
-            if (url.host().isEmpty()) {
-                url.setScheme("http");
-                url.setHost("fboom.me");
-            }
-            
-            followRedirect(url, SLOT(checkDownloadLink()));
+            followRedirect(redirect, SLOT(checkDownloadLink()));
         }
         else {
             emit error(tr("Maximum redirects reached"));
@@ -569,11 +499,10 @@ void FileBoomPlugin::checkDownloadLink() {
     const QString response = QString::fromUtf8(reply->readAll());
 
     if (FILE_REGEXP.indexIn(response) != -1) {
-        QUrl url(FILE_REGEXP.cap());
+        QString url = FILE_REGEXP.cap();
 
-        if (url.host().isEmpty()) {
-            url.setScheme("http");
-            url.setHost("fboom.me");
+        if (url.startsWith("/")) {
+            url.prepend(reply->url().scheme() + "://" + reply->url().authority());
         }
 
         emit downloadRequest(QNetworkRequest(url));
@@ -624,22 +553,8 @@ void FileBoomPlugin::checkLogin() {
         return;
     }
 
-    QUrl redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
-
-    if (redirect.isEmpty()) {
-        redirect = reply->header(QNetworkRequest::LocationHeader).toString();
-    }
-
-    reply->deleteLater();
-
-    if (!redirect.isEmpty()) {
-        if (m_redirects < MAX_REDIRECTS) {
-            followRedirect(redirect, SLOT(checkLogin()));
-            return;
-        }
-    }
-
     fetchDownloadRequest(m_url);
+    reply->deleteLater();
 }
 
 void FileBoomPlugin::startWaitTimer(int msecs, const char* slot) {
@@ -663,5 +578,5 @@ void FileBoomPlugin::stopWaitTimer() {
 }
 
 #if QT_VERSION < 0x050000
-Q_EXPORT_PLUGIN2(fileboom, FileBoomPlugin)
+Q_EXPORT_PLUGIN2(qdl2-fileboom, FileBoomPlugin)
 #endif
